@@ -140,6 +140,29 @@ def truecaser(
         click.echo(f"Error: {e}")
 
 
+@config.command()
+@click.option("--shard_size", help="Shard size to use when batch")
+@click.option("--src_seq_length", help="Src seq length to use when batch")
+@click.option("--tgt_seq_length", help="Tgt seq length to use when batch")
+@click.option("--project", "-p", "project_dir")
+@click.pass_context
+def prepare(
+    ctx: Context,
+    shard_size: str,
+    src_seq_length: str,
+    tgt_seq_length: str,
+    project_dir: str
+):
+    ctx.ensure_object(dict)
+    if project_dir is None:
+        project_dir = os.getcwd()
+    project_dir = pathlib.Path(project_dir)
+
+    Config.config_prepare(
+        str(shard_size), str(src_seq_length), str(tgt_seq_length), project_dir
+    )
+
+
 # Add processors
 @config.command()
 @click.option(
@@ -421,16 +444,28 @@ async def train(ctx: Context, gpu: int, continue_train: str):
 @click.option(
     "--log", help="Log file name"
 )
+@click.option(
+    "--debug", help="Debugging flag", is_flag=True
+)
 @click.pass_context
 async def eval(
-    ctx: Context, gpu: int, step: int, src: str, ref: str, out: str, log: str
+    ctx: Context,
+    gpu: int,
+    step: int,
+    src: str,
+    ref: str,
+    out: str,
+    log: str,
+    debug: bool
 ):
     try:
         workflow = Workflow.load(ctx.obj["project"])
         if src is not None:
             if ref is not None:
                 eval_stage = EvalStage(workflow)
-                await eval_stage.eval_files(gpu, step, src, ref, out, log)
+                await eval_stage.eval_files(
+                    gpu, step, src, ref, out, log, debug
+                )
             else:
                 print("Reference path missing")
         else:
